-- line 826 after hooking the main file, subtract from the line number in error trace

-- tLOG = import('/mods/common/modules/tools.lua').tLOG

local apmlog = {}

local actionsTotal = 0
local commandsTotal = 0

-- Modified OnCommandIssued to update the apmlog table and recalculate APM
do
    local _OnCommandIssued = OnCommandIssued
    function OnCommandIssued(command)
        _OnCommandIssued(command)

        commandsTotal = commandsTotal + 1
        local gameTime = GetGameTimeSeconds()

        -- Initialize apmlog[gameTime] only if it does not exist
        if not apmlog[gameTime] then
            apmlog[gameTime] = {}
            actionsTotal = actionsTotal + 1
        end

        -- Increment the command count for the specified command type
        apmlog[gameTime][command.CommandType] = (apmlog[gameTime][command.CommandType] or 0) + 1

        -- Calculate APM and update UI
        local apm = calculateAPM()
        UpdateAPMPanel(apm) -- Function to update the APM display panel
    end
end

-- Function to calculate APM over the last minute
function calculateAPM()
    local currentTime = GetGameTimeSeconds()
    local oneMinuteAgo = currentTime - 60

    -- Remove timestamps older than one minute
    for gameTime, v in pairs(apmlog) do
        if gameTime < oneMinuteAgo then
            apmlog[gameTime] = nil -- Remove the entry by setting it to nil
        end
    end

    -- Calculate APM based on the remaining timestamps
    local apm = table.count(apmlog) -- Or use `table.count` if you have it defined
    return apm
end

-- Placeholder function for updating APM panel (replace with actual UI update code)
function UpdateAPMPanel(apm)
    LOG("Current APM: " ..
        tostring(apm) ..
        " .. Total actions: " .. tostring(actionsTotal) .. " .. Total commands: " .. tostring(commandsTotal))

    -- tLOG(apmlog, "apmlog")

    -- Here, add code to update the UI panel with the APM value
end

-- Utitility funcion to log tables (or anything)
function tLOG(this, key, indentLevel)
    if not indentLevel then indentLevel = 0 end

    local indent = string.rep('-   ', indentLevel)
    local first = indent .. tostring(key) .. ': '

    if type(this) == 'nil' then
        LOG(first .. 'nil')
        return
    elseif type(this) == 'string' then
        LOG(first .. '"' .. this .. '"')
        return
    elseif type(this) == 'boolean' then
        LOG(first .. tostring(this))
        return
    elseif type(this) == 'function' then
        LOG(first .. 'function')
        return
    elseif type(this) == 'table' then
        if next(this) == nil then
            LOG(first .. '{} (empty table)')
            return
        end
        LOG(first .. "{")
        for innerKey, innerValue in pairs(this) do
            tLOG(innerValue, innerKey, indentLevel + 1) -- Only this call now logs each key-value pair
        end
        LOG(indent .. "}")
    else
        LOG(first .. tostring(this)) -- Handles numbers and other types
    end
end
